@@ -1,6 +1,7 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /* libwpd
  * Copyright (C) 2006 Fridrich Strba (fridrich.strba@bluewin.ch)
- *  
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
@@ -18,17 +19,17 @@
  * For further information visit http://libwpd.sourceforge.net
  */
 
-/* "This product is not manufactured, approved, or supported by 
+/* "This product is not manufactured, approved, or supported by
  * Corel Corporation or Corel Corporation Limited."
  */
 
 #include "libwpd_internal.h"
 #include "WP1CenterTextGroup.h"
 
-WP1CenterTextGroup::WP1CenterTextGroup(WPXInputStream *input, uint8_t group) :
+WP1CenterTextGroup::WP1CenterTextGroup(WPXInputStream *input, WPXEncryption *encryption, uint8_t group) :
 	WP1FixedLengthGroup(group)
 {
-	_read(input);
+	_read(input, encryption);
 }
 
 WP1CenterTextGroup::~WP1CenterTextGroup()
@@ -40,3 +41,4 @@ void WP1CenterTextGroup::parse(WP1Listener *listener)
 	WPD_DEBUG_MSG(("WordPerfect: handling the Center Text group\n"));
 	listener->centerOn();
 }
+/* vim:set shiftwidth=4 softtabstop=4 noexpandtab: */
