@@ -1,6 +1,7 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /* libwpd
  * Copyright (C) 2006 Fridrich Strba (fridrich.strba@bluewin.ch)
- *  
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
@@ -18,7 +19,7 @@
  * For further information visit http://libwpd.sourceforge.net
  */
 
-/* "This product is not manufactured, approved, or supported by 
+/* "This product is not manufactured, approved, or supported by
  * Corel Corporation or Corel Corporation Limited."
  */
 
@@ -26,33 +27,33 @@
 #include "libwpd_internal.h"
 #include <vector>
 
-WP1SetTabsGroup::WP1SetTabsGroup(WPXInputStream *input, uint8_t group) :
+WP1SetTabsGroup::WP1SetTabsGroup(WPXInputStream *input, WPXEncryption *encryption, uint8_t group) :
 	WP1VariableLengthGroup(group),
 	m_tabStops(std::vector<WPXTabStop>())
 {
-	_read(input);
+	_read(input, encryption);
 }
 
 WP1SetTabsGroup::~WP1SetTabsGroup()
 {
 }
 
-void WP1SetTabsGroup::_readContents(WPXInputStream *input)
+void WP1SetTabsGroup::_readContents(WPXInputStream *input, WPXEncryption *encryption)
 {
 	// Skip first the old condensed tab table
-	while (readU8(input) != 0xff && !input->atEOS())
+	while (readU8(input, encryption) != 0xff && !input->atEOS())
 		input->seek(2, WPX_SEEK_CUR);
 
 	// Now read the new condensed tab table
 	int8_t tmpTabType = 0;
-	float tmpTabPosition = 0.0f;
+	double tmpTabPosition = 0.0;
 	WPXTabStop tmpTabStop = WPXTabStop();
 
-	while (((tmpTabType = read8(input)) & 0xff) != 0xff)
+	while (((tmpTabType = (int8_t)readU8(input, encryption)) & 0xff) != 0xff)
 	{
 		if (input->atEOS())
 			throw FileException();
-		tmpTabPosition = (float)((double)readU16(input, true) / 72.0f);
+		tmpTabPosition = (double)((double)readU16(input, encryption, true) / 72.0);
 
 		if (tmpTabType < 0)
 		{
@@ -97,7 +98,7 @@ void WP1SetTabsGroup::_readContents(WPXInputStream *input)
 			}
 
 			m_tabStops.push_back(tmpTabStop);
-		}	
+		}
 	}
 }
 
@@ -113,3 +114,4 @@ void WP1SetTabsGroup::parse(WP1Listener *listener)
 #endif
 	listener->setTabs(m_tabStops);
 }
+/* vim:set shiftwidth=4 softtabstop=4 noexpandtab: */
