@@ -1,8 +1,9 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /* libwpd
  * Copyright (C) 2002 William Lachance (wrlach@gmail.com)
  * Copyright (C) 2002 Marc Maurer (uwog@uwog.net)
  * Copyright (C) 2004 Fridrich Strba (fridrich.strba@bluewin.ch)
- *  
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
@@ -20,7 +21,7 @@
  * For further information visit http://libwpd.sourceforge.net
  */
 
-/* "This product is not manufactured, approved, or supported by 
+/* "This product is not manufactured, approved, or supported by
  * Corel Corporation or Corel Corporation Limited."
  */
 
@@ -32,13 +33,13 @@
 
 class WP3MiscellaneousGroup : public WP3VariableLengthGroup
 {
- public:
-	WP3MiscellaneousGroup(WPXInputStream *input);	
+public:
+	WP3MiscellaneousGroup(WPXInputStream *input, WPXEncryption *encryption);
 	~WP3MiscellaneousGroup();
-	void _readContents(WPXInputStream *input);
+	void _readContents(WPXInputStream *input, WPXEncryption *encryption);
 	void parse(WP3Listener *listener);
 
- private:
+private:
 	// variables needed for subgroup 4 (Page Size Override)
 	uint16_t m_pageWidth;
 	uint16_t m_pageHeight;
@@ -46,3 +47,4 @@ class WP3MiscellaneousGroup : public WP3VariableLengthGroup
 };
 
 #endif /* WP3MISCELLANEOUSGROUP_H */
+/* vim:set shiftwidth=4 softtabstop=4 noexpandtab: */
